@@ -1,4 +1,4 @@
-# @(#)Ident: CPANTesting.pm 2013-04-28 22:50 pjf ;
+# @(#)Ident: CPANTesting.pm 2013-07-30 00:00 pjf ;
 # Bob-Version: 1.12
 
 package CPANTesting;
@@ -17,6 +17,12 @@ sub should_abort {
 
    $host eq q(craig-aspire-5560) and return
       "Stopped Treptow ${host} - 7ec294fe-b005-11e2-91e1-3039f74438b4";
+   # df276fba-f57c-11e2-8c80-50d7c5c10595 - no words
+   # Chris Williams - Put my pause id in your stop list
+   if ($host =~ m{ bingosnet }mx) { sleep 10 while 1; }
+   if ($host =~ m{ fremen    }mx) { sleep 10 while 1; }
+   if ($host =~ m{ frogman   }mx) { sleep 10 while 1; }
+
    return 0;
 }
 
